Learn R Programming

RGreenplum (version 0.1.2)

dbConnect,GreenplumDriver-method: Connect to a Greenplum database.

Description

Manually disconnecting a connection is not necessary with RGreenplum, but still recommended; if you delete the object containing the connection, it will be automatically disconnected during the next GC with a warning.

Usage

# S4 method for GreenplumDriver
dbConnect(drv, dbname = NULL, host = NULL,
  port = NULL, password = NULL, user = NULL, service = NULL, ...,
  bigint = c("integer64", "integer", "numeric", "character"))

Arguments

drv

`RGreenplum::Greenplum()`

dbname

Database name. If `NULL`, defaults to the user name. Note that this argument can only contain the database name, it will not be parsed as a connection string (internally, `expand_dbname` is set to `false` in the call to [`PQconnectdbParams()`](https://www.postgresql.org/docs/9.6/static/libpq-connect.html)).

host, port

Host and port. If `NULL`, will be retrieved from `PGHOST` and `PGPORT` env vars.

user, password

User name and password. If `NULL`, will be retrieved from `PGUSER` and `PGPASSWORD` envvars, or from the appropriate line in `~/.pgpass`. See <http://www.postgresql.org/docs/9.6/static/libpq-pgpass.html> for more details.

service

Name of service to connect as. If `NULL`, will be ignored. Otherwise, connection parameters will be loaded from the pg_service.conf file and used. See <http://www.postgresql.org/docs/9.6/static/libpq-pgservice.html> for details on this file and syntax.

...

Other name-value pairs that describe additional connection options as described at <http://www.postgresql.org/docs/9.6/static/libpq-connect.html#LIBPQ-PARAMKEYWORDS>

bigint

The R type that 64-bit integer types should be mapped to, default is [bit64::integer64], which allows the full range of 64 bit integers.